function nds = nuderst(pars)
%NUDERST        Selects the step size for numerical differentiation
%
%   NDS = nuderst(PARS)
%
%   PARS: The parameters, a row vector.
%   NDS: A row vector, whose k:th element is the step size to be used
%        for numerical differentiation with respect to the k:th parameter

%   L. Ljung 10-2-90
%   Copyright 1986-2000 The MathWorks, Inc.
%   $Revision: 1.4 $  $Date: 2000/06/15 11:40:02 $

nds = max(1e-7*ones(1,length(pars)),abs(pars(:)')*1e-4);
